'____________________________________________
'            D A T A   V A L I D A T I O N   C L A S S

'                                  Ron Kessler
'                           Created 3/27/2008
'____________________________________________
'Updated 3/27/08


'This class can be used to validate form data in your projects. This version will validate:
'   String
'   Decimal
'   Integer
'   Ranges
'   Missing/null data

Public Class DataValidation

    ''' <summary>
    ''' This method makes sure the textbox contains some data. Accepts the textbox control and a description
    ''' as string.
    ''' </summary>
    ''' <param name="textbox"></param>
    ''' <param name="name"></param>
    ''' <returns>Boolean True if textbox contains data and false if it is blank</returns>
    ''' <remarks></remarks>
    Public Function IsPresent(ByVal textbox As TextBox, ByVal name As String) As Boolean

        If textbox.Text = String.Empty Then
            MessageBox.Show(name & " is a required field.", "Missing Information")
            textbox.Select()
            Return False
        Else
            Return True
        End If
    End Function


    ''' <summary>
    ''' This method tests string for A-Z characters. Accepts the textbox and a description as string.
    ''' </summary>
    ''' <param name="textbox"></param>
    ''' <param name="name"></param>
    ''' <returns>Returns True if string contains A-Z and false is anything else.</returns>
    ''' <remarks></remarks>
    Public Function IsString(ByVal textbox As TextBox, ByVal name As String) As Boolean

        Dim tempString As String = textbox.Text
        Dim x As Integer = 1
        For x = 1 To tempString.Length
            If Not Mid(UCase(tempString), x, 1) Like "[A-Z]" Then
                MessageBox.Show(name & " must be text.", "Incorrect format.", _
                    MessageBoxButtons.OK, MessageBoxIcon.Error)

                textbox.Clear()
                textbox.Select()
                Return False
            End If
        Next

        Return True


    End Function

    ''' <summary>
    ''' This method makes sure the textbox contains an integer. Accepts the textbox control and a description
    ''' as string.
    ''' </summary>
    ''' <param name="textbox"></param>
    ''' <param name="name"></param>
    ''' <returns>Boolean True if textbox contains data and false if it is blank</returns>
    ''' <remarks></remarks>
    Public Function IsInteger(ByVal textbox As TextBox, ByVal name As String) As Boolean

        Dim x As Integer = 0

        If Not Integer.TryParse(textbox.Text, x) Then
            MessageBox.Show(name & " must be an integer value.", "Incorrect Data", MessageBoxButtons.OK, MessageBoxIcon.Error)
            textbox.Select()
            Return False
        Else
            Return True

        End If
    End Function

    ''' <summary>
    ''' This method makes sure the textbox contains a decimal. Accepts the textbox control and a description
    ''' as string.
    ''' </summary>
    ''' <param name="textbox"></param>
    ''' <param name="name"></param>
    ''' <returns>Boolean True if textbox contains data and false if it is blank</returns>
    ''' <remarks></remarks>
    Public Function IsDecimal(ByVal textbox As TextBox, ByVal name As String) As Boolean

        Dim x As Decimal = 0

        If Not Decimal.TryParse(textbox.Text, x) Then
            MessageBox.Show(name & " must be currency value.", "Incorrect Data", _
                MessageBoxButtons.OK, MessageBoxIcon.Error)
            textbox.Select()
            Return False
        Else
            Return True
        End If
    End Function


    ''' <summary>
    ''' This method makes sure the textbox contains a valid date. Accepts the textbox control and a description
    ''' as string.
    ''' </summary>
    ''' <param name="maskedTextBox"></param>
    ''' <param name="name"></param>
    ''' <returns>Boolean True if textbox contains data and false if it is blank</returns>
    ''' <remarks></remarks>
    Public Function IsDate(ByVal maskedTextBox As MaskedTextBox, ByVal name As String) As Boolean

        Dim x As Date

        If Not Date.TryParse(maskedTextBox.Text, x) Then
            MessageBox.Show(name & " must be in date format.", "Incorrect Birth Date Format", _
                MessageBoxButtons.OK, MessageBoxIcon.Error)
            maskedTextBox.Select()
            Return False
        Else
            Return True
        End If

    End Function

    ''' <summary>
    ''' The method tests for accurate range of data. It accepts the name of the textbox, a description as string,
    ''' a minimum value as decimal, and a maximum value as decimal.
    ''' </summary>
    ''' <param name="textbox"></param>
    ''' <param name="name"></param>
    ''' <param name="min"></param>
    ''' <param name="max"></param>
    ''' <returns>Returns true if the value is within the Min and Max parameters.</returns>
    ''' <remarks></remarks>
    Public Function IsWithinRange(ByVal textbox As TextBox, ByVal name As String, _
            ByVal min As Decimal, ByVal max As Decimal) As Boolean

        Dim x As Decimal = CDec(textbox.Text)
        If x < min OrElse x > max Then
            MessageBox.Show(name & " must be between " _
                & FormatCurrency(min) & " and " & FormatCurrency(max) & ".", _
                "Unacceptable Deposit Amount ", MessageBoxButtons.OK, MessageBoxIcon.Error)
            textbox.Select()
            Return False
        Else
            Return True
        End If

    End Function
End Class
